==> jc-1.4.0.tar.gz: java/util/Collections__241.c <==
// final class java.util.Collections$1

// class file dependencies
// @dep_class bf29ff960d5ec1d0 java_lang_Class
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class c80f4aedd95be265 java_lang_String
// @dep_class b9990a4782a86617 java_util_Collections__241
// @dep_class c56a8b1934689c38 java_util_Enumeration
// @dep_class be56ff673eefd9d2 java_util_Iterator

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Collections__241
// @dep_header java_util_Enumeration
// @dep_header java_util_Iterator

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Collections__241.h"
#include "java/util/Enumeration.h"
#include "java/util/Iterator.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// final java.util.Iterator val$i
static _jc_field _jc_java_util_Collections__241$field_info$val__24i = {
	.name=		"val$i",
	.signature=	"Ljava/util/Iterator;",
	.class=		&_jc_java_util_Collections__241$type,
	.type=		&_jc_java_util_Iterator$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_java_util_Collections__241$object, refs[-1].java_util_Collections__241.val__24i),
};

// Fields
static _jc_field *const _jc_java_util_Collections__241$fields[] = {
	&_jc_java_util_Collections__241$field_info$val__24i
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(java.util.Iterator)
//

static _jc_linenum _jc_java_util_Collections__241$linenum_table$_init$fb346656e80483e8[];

static const unsigned char _jc_java_util_Collections__241$param_ptypes$_init$fb346656e80483e8[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_util_Collections__241$param_types$_init$fb346656e80483e8[] = {
	&_jc_java_util_Iterator$type
};

_jc_method _jc_java_util_Collections__241$method_info$_init$fb346656e80483e8 = {
	.name=			"<init>",
	.signature=		"(Ljava/util/Iterator;)V",
	.class=			&_jc_java_util_Collections__241$type,
	.param_types=		&_jc_java_util_Collections__241$param_types$_init$fb346656e80483e8,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_util_Collections__241$param_ptypes$_init$fb346656e80483e8,
	.signature_hash=	_JC_JLONG(0xfb346656e80483e8),
	.access_flags=		0,
	.function=		&_jc_java_util_Collections__241$method$_init$fb346656e80483e8,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_util_Collections__241$linenum_table$_init$fb346656e80483e8
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_util_Collections__241, _init$fb346656e80483e8);

void
_jc_java_util_Collections__241$method$_init$fb346656e80483e8(_jc_env *const env, _jc_java_util_Collections__241$object *this, _jc_object *param0)
{
	struct _jc_java_util_Collections__241$object *r0;
	struct _jc_object *r1;

	r0 = this;
	r1 = param0;
	_JC_REF_FIELD(env, r0, java_util_Collections__241, val__24i) = r1;
	_JC_LINE_NUMBER(742);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final boolean hasMoreElements()
//

static _jc_linenum _jc_java_util_Collections__241$linenum_table$hasMoreElements$95fbe58f36adadb0[];

static const unsigned char _jc_java_util_Collections__241$param_ptypes$hasMoreElements$95fbe58f36adadb0[] = { 
_JC_TYPE_BOOLEAN };

_jc_method _jc_java_util_Collections__241$method_info$hasMoreElements$95fbe58f36adadb0 = {
	.name=			"hasMoreElements",
	.signature=		"()Z",
	.class=			&_jc_java_util_Collections__241$type,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_java_util_Collections__241$param_ptypes$hasMoreElements$95fbe58f36adadb0,
	.signature_hash=	_JC_JLONG(0x95fbe58f36adadb0),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_util_Collections__241$method$hasMoreElements$95fbe58f36adadb0,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_util_Collections__241$vtable, java_util_Collections__241.hasMoreElements$95fbe58f36adadb0) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_util_Collections__241$linenum_table$hasMoreElements$95fbe58f36adadb0
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_util_Collections__241, hasMoreElements$95fbe58f36adadb0);

jboolean
_jc_java_util_Collections__241$method$hasMoreElements$95fbe58f36adadb0(_jc_env *const env, _jc_java_util_Collections__241$object *this)
{
	struct _jc_java_util_Collections__241$object *r0;
	struct _jc_object *r1;
	jboolean z0;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(752);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_util_Collections__241, val__24i);
	z0 = _JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0xfb0bd5e38c59ddcd), jboolean);
	return z0;
}

//
// public final java.lang.Object nextElement()
//

static _jc_linenum _jc_java_util_Collections__241$linenum_table$nextElement$9b7c3789fa3ba818[];

static const unsigned char _jc_java_util_Collections__241$param_ptypes$nextElement$9b7c3789fa3ba818[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_util_Collections__241$method_info$nextElement$9b7c3789fa3ba818 = {
	.name=			"nextElement",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_java_util_Collections__241$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_java_util_Collections__241$param_ptypes$nextElement$9b7c3789fa3ba818,
	.signature_hash=	_JC_JLONG(0x9b7c3789fa3ba818),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_util_Collections__241$method$nextElement$9b7c3789fa3ba818,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_util_Collections__241$vtable, java_util_Collections__241.nextElement$9b7c3789fa3ba818) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_util_Collections__241$linenum_table$nextElement$9b7c3789fa3ba818
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_util_Collections__241, nextElement$9b7c3789fa3ba818);

_jc_java_lang_Object$object *
_jc_java_util_Collections__241$method$nextElement$9b7c3789fa3ba818(_jc_env *const env, _jc_java_util_Collections__241$object *this)
{
	struct _jc_java_util_Collections__241$object *r0;
	struct _jc_object *r1;
	struct _jc_java_lang_Object$object *r2;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(763);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_util_Collections__241, val__24i);
	r2 = _JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0x5874f79a1cf66ea), _jc_object *);
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_util_Collections__241$methods[] = {
	&_jc_java_util_Collections__241$method_info$_init$fb346656e80483e8,
	&_jc_java_util_Collections__241$method_info$hasMoreElements$95fbe58f36adadb0,
	&_jc_java_util_Collections__241$method_info$nextElement$9b7c3789fa3ba818
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_java_util_Collections__241$interfaces[] = {
	&_jc_java_util_Enumeration$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_java_util_Collections__241$imethod_hash_bucket_24[] = {
	&_jc_java_util_Collections__241$method_info$nextElement$9b7c3789fa3ba818,
	_JC_NULL
};
static _jc_method *_jc_java_util_Collections__241$imethod_hash_bucket_48[] = {
	&_jc_java_util_Collections__241$method_info$hasMoreElements$95fbe58f36adadb0,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_java_util_Collections__241$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[24]=	_jc_java_util_Collections__241$imethod_hash_bucket_24,
	[48]=	_jc_java_util_Collections__241$imethod_hash_bucket_48
};

// Interface "quick" lookup hash table
static const void *_jc_java_util_Collections__241$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[24]=	&_jc_java_util_Collections__241$method$nextElement$9b7c3789fa3ba818,
	[48]=	&_jc_java_util_Collections__241$method$hasMoreElements$95fbe58f36adadb0
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_util_Collections__241$instanceof_hash_bucket_23[] = {
	&_jc_java_util_Collections__241$type,
	_JC_NULL
};
static _jc_type *const _jc_java_util_Collections__241$instanceof_hash_bucket_56[] = {
	&_jc_java_util_Enumeration$type,
	_JC_NULL
};
static _jc_type *const _jc_java_util_Collections__241$instanceof_hash_bucket_113[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_util_Collections__241$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[23]=	_jc_java_util_Collections__241$instanceof_hash_bucket_23,
	[56]=	_jc_java_util_Collections__241$instanceof_hash_bucket_56,
	[113]=	_jc_java_util_Collections__241$instanceof_hash_bucket_113
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_util_Collections__241$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0xbf29ff960d5ec1d0) },
	{ "java/lang/Object",	_JC_JLONG(0x2a7152deee1944f1) },
	{ "java/lang/String",	_JC_JLONG(0xc80f4aedd95be265) },
	{ "java/util/Enumeration",	_JC_JLONG(0xc56a8b1934689c38) },
	{ "java/util/Iterator",	_JC_JLONG(0xbe56ff673eefd9d2) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_util_Collections__241$vtype _jc_java_util_Collections__241$type = {
    .type= {
	.name=			"java/util/Collections$1",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_java_util_Collections__241$interfaces) / sizeof(*_jc_java_util_Collections__241$interfaces),
	.interfaces=		_jc_java_util_Collections__241$interfaces,
	.imethod_hash_table=	_jc_java_util_Collections__241$imethod_hash_table,
	.imethod_quick_table=	_jc_java_util_Collections__241$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0xb9990a4782a86617),
		.source_file=		"Collections.java",
		.instance_size=		sizeof(_jc_java_util_Collections__241$refs) + sizeof(_jc_java_util_Collections__241$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_java_util_Collections__241$fields) / sizeof(*_jc_java_util_Collections__241$fields),
		.fields=		_jc_java_util_Collections__241$fields,
		.num_methods=		sizeof(_jc_java_util_Collections__241$methods) / sizeof(*_jc_java_util_Collections__241$methods),
		.methods=		_jc_java_util_Collections__241$methods,
		.instanceof_hash_table=	_jc_java_util_Collections__241$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_util_Collections__241$class_depends) / sizeof(*_jc_java_util_Collections__241$class_depends),
		.class_depends=		_jc_java_util_Collections__241$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_util_Collections__241= {
	    .hasMoreElements$95fbe58f36adadb0=
		&_jc_java_util_Collections__241$method$hasMoreElements$95fbe58f36adadb0,
	    .nextElement$9b7c3789fa3ba818=
		&_jc_java_util_Collections__241$method$nextElement$9b7c3789fa3ba818,
	},
    }
};

==> jc-1.4.5.tar.gz: java/util/Collections__241.c <==
// final class java.util.Collections$1

// class file dependencies
// @dep_class 764eb76bc6714ae3 java_lang_Class
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 195095aa45046bea java_lang_String
// @dep_class b9990a4782a86617 java_util_Collections__241
// @dep_class c56a8b1934689c38 java_util_Enumeration
// @dep_class be56ff673eefd9d2 java_util_Iterator

// header file dependencies
// @dep_header java_lang_Class
// @dep_header java_lang_String
// @dep_header java_util_Collections__241
// @dep_header java_util_Enumeration
// @dep_header java_util_Iterator

#include "jc_defs.h"

#include "java/lang/Class.h"
#include "java/lang/String.h"
#include "java/util/Collections__241.h"
#include "java/util/Enumeration.h"
#include "java/util/Iterator.h"

/************************************************************************
 *				  Fields				*
 ************************************************************************/

// final java.util.Iterator val$i
static _jc_field _jc_java_util_Collections__241$field_info$val__24i = {
	.name=		"val$i",
	.signature=	"Ljava/util/Iterator;",
	.class=		&_jc_java_util_Collections__241$type,
	.type=		&_jc_java_util_Iterator$type,
	.access_flags=	_JC_ACC_FINAL,
	.offset=	_JC_OFFSETOF(_jc_java_util_Collections__241$object, refs[-1].java_util_Collections__241.val__24i),
};

// Fields
static _jc_field *const _jc_java_util_Collections__241$fields[] = {
	&_jc_java_util_Collections__241$field_info$val__24i
};

/************************************************************************
 *			       Constructors				*
 ************************************************************************/

//
// void <init>(java.util.Iterator)
//

static _jc_linenum _jc_java_util_Collections__241$linenum_table$_init$fb346656e80483e8[];

static const unsigned char _jc_java_util_Collections__241$param_ptypes$_init$fb346656e80483e8[] = { 
_JC_TYPE_REFERENCE, _JC_TYPE_VOID };

static _jc_type *const _jc_java_util_Collections__241$param_types$_init$fb346656e80483e8[] = {
	&_jc_java_util_Iterator$type
};

_jc_method _jc_java_util_Collections__241$method_info$_init$fb346656e80483e8 = {
	.name=			"<init>",
	.signature=		"(Ljava/util/Iterator;)V",
	.class=			&_jc_java_util_Collections__241$type,
	.param_types=		&_jc_java_util_Collections__241$param_types$_init$fb346656e80483e8,
	.return_type=		&_jc_void$prim$type,
	.param_ptypes=		&_jc_java_util_Collections__241$param_ptypes$_init$fb346656e80483e8,
	.signature_hash=	_JC_JLONG(0xfb346656e80483e8),
	.access_flags=		0,
	.function=		&_jc_java_util_Collections__241$method$_init$fb346656e80483e8,
	.num_parameters=	1,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_util_Collections__241$linenum_table$_init$fb346656e80483e8
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_util_Collections__241, _init$fb346656e80483e8);

void _JC_JCNI_ATTR
_jc_java_util_Collections__241$method$_init$fb346656e80483e8(_jc_env *const env, _jc_java_util_Collections__241$object *this, _jc_object *param0)
{
	struct _jc_java_util_Collections__241$object *r0;
	struct _jc_object *r1;

	r0 = this;
	r1 = param0;
	_JC_REF_FIELD(env, r0, java_util_Collections__241, val__24i) = r1;
	_JC_LINE_NUMBER(742);				// 0
	return;
}

/************************************************************************
 *			     Instance methods				*
 ************************************************************************/

//
// public final boolean hasMoreElements()
//

static _jc_linenum _jc_java_util_Collections__241$linenum_table$hasMoreElements$95fbe58f36adadb0[];

static const unsigned char _jc_java_util_Collections__241$param_ptypes$hasMoreElements$95fbe58f36adadb0[] = { 
_JC_TYPE_BOOLEAN };

_jc_method _jc_java_util_Collections__241$method_info$hasMoreElements$95fbe58f36adadb0 = {
	.name=			"hasMoreElements",
	.signature=		"()Z",
	.class=			&_jc_java_util_Collections__241$type,
	.return_type=		&_jc_boolean$prim$type,
	.param_ptypes=		&_jc_java_util_Collections__241$param_ptypes$hasMoreElements$95fbe58f36adadb0,
	.signature_hash=	_JC_JLONG(0x95fbe58f36adadb0),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_util_Collections__241$method$hasMoreElements$95fbe58f36adadb0,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_util_Collections__241$vtable, java_util_Collections__241.hasMoreElements$95fbe58f36adadb0) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_util_Collections__241$linenum_table$hasMoreElements$95fbe58f36adadb0
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_util_Collections__241, hasMoreElements$95fbe58f36adadb0);

jboolean _JC_JCNI_ATTR
_jc_java_util_Collections__241$method$hasMoreElements$95fbe58f36adadb0(_jc_env *const env, _jc_java_util_Collections__241$object *this)
{
	struct _jc_java_util_Collections__241$object *r0;
	struct _jc_object *r1;
	jboolean z0;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(752);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_util_Collections__241, val__24i);
	z0 = _JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0xfb0bd5e38c59ddcd), jboolean, (_jc_env *, struct _jc_object *));
	return z0;
}

//
// public final java.lang.Object nextElement()
//

static _jc_linenum _jc_java_util_Collections__241$linenum_table$nextElement$9b7c3789fa3ba818[];

static const unsigned char _jc_java_util_Collections__241$param_ptypes$nextElement$9b7c3789fa3ba818[] = { 
_JC_TYPE_REFERENCE };

_jc_method _jc_java_util_Collections__241$method_info$nextElement$9b7c3789fa3ba818 = {
	.name=			"nextElement",
	.signature=		"()Ljava/lang/Object;",
	.class=			&_jc_java_util_Collections__241$type,
	.return_type=		&_jc_java_lang_Object$type,
	.param_ptypes=		&_jc_java_util_Collections__241$param_ptypes$nextElement$9b7c3789fa3ba818,
	.signature_hash=	_JC_JLONG(0x9b7c3789fa3ba818),
	.access_flags=		_JC_ACC_PUBLIC|_JC_ACC_FINAL,
	.function=		&_jc_java_util_Collections__241$method$nextElement$9b7c3789fa3ba818,
	.vtable_index=		_JC_OFFSETOF(struct _jc_java_util_Collections__241$vtable, java_util_Collections__241.nextElement$9b7c3789fa3ba818) / sizeof(void *),
	.num_parameters=	0,
	.u= { .exec= {
	  .u= {
	    .linenum= {
	      .len=	1,
	      .table=	_jc_java_util_Collections__241$linenum_table$nextElement$9b7c3789fa3ba818
	    },
	  },
	} },
};

_JC_LINENUM_TABLE(java_util_Collections__241, nextElement$9b7c3789fa3ba818);

_jc_java_lang_Object$object * _JC_JCNI_ATTR
_jc_java_util_Collections__241$method$nextElement$9b7c3789fa3ba818(_jc_env *const env, _jc_java_util_Collections__241$object *this)
{
	struct _jc_java_util_Collections__241$object *r0;
	struct _jc_object *r1;
	struct _jc_java_lang_Object$object *r2;

	// Check for stack overflow
	_JC_STACK_OVERFLOW_CHECK(env);

	r0 = this;
	_JC_LINE_NUMBER(763);				// 0
	r1 = _JC_REF_FIELD(env, r0, java_util_Collections__241, val__24i);
	r2 = _JC_INVOKE_INTERFACE(env, r1, _JC_JLONG(0x5874f79a1cf66ea), _jc_object *, (_jc_env *, struct _jc_object *));
	return r2;
}

/************************************************************************
 *			       Method list				*
 ************************************************************************/

// Methods
static _jc_method *const _jc_java_util_Collections__241$methods[] = {
	&_jc_java_util_Collections__241$method_info$_init$fb346656e80483e8,
	&_jc_java_util_Collections__241$method_info$hasMoreElements$95fbe58f36adadb0,
	&_jc_java_util_Collections__241$method_info$nextElement$9b7c3789fa3ba818
};

/************************************************************************
 *			      Interface list				*
 ************************************************************************/

// Directly implemented interfaces
static _jc_type *const _jc_java_util_Collections__241$interfaces[] = {
	&_jc_java_util_Enumeration$type
};

/************************************************************************
 *			   Interface hash table				*
 ************************************************************************/

#if _JC_IMETHOD_HASHSIZE != 128
#error "_JC_IMETHOD_HASHSIZE has the wrong value (should be 128)"
#endif

// Interface lookup hash table buckets
static _jc_method *_jc_java_util_Collections__241$imethod_hash_bucket_24[] = {
	&_jc_java_util_Collections__241$method_info$nextElement$9b7c3789fa3ba818,
	_JC_NULL
};
static _jc_method *_jc_java_util_Collections__241$imethod_hash_bucket_48[] = {
	&_jc_java_util_Collections__241$method_info$hasMoreElements$95fbe58f36adadb0,
	_JC_NULL
};

// Interface lookup hash table
static _jc_method **_jc_java_util_Collections__241$imethod_hash_table[_JC_IMETHOD_HASHSIZE] = {
	[24]=	_jc_java_util_Collections__241$imethod_hash_bucket_24,
	[48]=	_jc_java_util_Collections__241$imethod_hash_bucket_48
};

// Interface "quick" lookup hash table
static const void *_jc_java_util_Collections__241$imethod_quick_table[_JC_IMETHOD_HASHSIZE] = {
	[24]=	&_jc_java_util_Collections__241$method$nextElement$9b7c3789fa3ba818,
	[48]=	&_jc_java_util_Collections__241$method$hasMoreElements$95fbe58f36adadb0
};

/************************************************************************
 *			  Instanceof hash table				*
 ************************************************************************/

#if _JC_INSTANCEOF_HASHSIZE != 128
#error "_JC_INSTANCEOF_HASHSIZE has the wrong value (should be 128)"
#endif

// Instanceof hash table buckets
static _jc_type *const _jc_java_util_Collections__241$instanceof_hash_bucket_23[] = {
	&_jc_java_util_Collections__241$type,
	_JC_NULL
};
static _jc_type *const _jc_java_util_Collections__241$instanceof_hash_bucket_56[] = {
	&_jc_java_util_Enumeration$type,
	_JC_NULL
};
static _jc_type *const _jc_java_util_Collections__241$instanceof_hash_bucket_101[] = {
	&_jc_java_lang_Object$type,
	_JC_NULL
};

// Instanceof hash table
static _jc_type *const *const _jc_java_util_Collections__241$instanceof_hash_table[_JC_INSTANCEOF_HASHSIZE] = {
	[23]=	_jc_java_util_Collections__241$instanceof_hash_bucket_23,
	[56]=	_jc_java_util_Collections__241$instanceof_hash_bucket_56,
	[101]=	_jc_java_util_Collections__241$instanceof_hash_bucket_101
};

/************************************************************************
 *			     Dependency list				*
 ************************************************************************/

// Class dependency info
static _jc_class_depend _jc_java_util_Collections__241$class_depends[] = {
	{ "java/lang/Class",	_JC_JLONG(0x764eb76bc6714ae3) },
	{ "java/lang/Object",	_JC_JLONG(0x1c4f1fc002fc96e5) },
	{ "java/lang/String",	_JC_JLONG(0x195095aa45046bea) },
	{ "java/util/Enumeration",	_JC_JLONG(0xc56a8b1934689c38) },
	{ "java/util/Iterator",	_JC_JLONG(0xbe56ff673eefd9d2) },
};

/************************************************************************
 *				Class info				*
 ************************************************************************/

// Class info
_jc_java_util_Collections__241$vtype _jc_java_util_Collections__241$type = {
    .type= {
	.name=			"java/util/Collections$1",
	.superclass=		&_jc_java_lang_Object$type,
	.access_flags=		_JC_ACC_FINAL,
	.flags=			_JC_TYPE_REFERENCE,
	.num_interfaces=sizeof(_jc_java_util_Collections__241$interfaces) / sizeof(*_jc_java_util_Collections__241$interfaces),
	.interfaces=		_jc_java_util_Collections__241$interfaces,
	.imethod_hash_table=	_jc_java_util_Collections__241$imethod_hash_table,
	.imethod_quick_table=	_jc_java_util_Collections__241$imethod_quick_table,
	.u= {
	    .nonarray= {
		.block_size_index=	_JC_LIBJC_VERSION,
		.num_vmethods=		13,
		.hash=			_JC_JLONG(0xb9990a4782a86617),
		.source_file=		"Collections.java",
		.instance_size=		sizeof(_jc_java_util_Collections__241$refs) + sizeof(_jc_java_util_Collections__241$object),
		.num_virtual_refs=	1,
		.num_fields=		sizeof(_jc_java_util_Collections__241$fields) / sizeof(*_jc_java_util_Collections__241$fields),
		.fields=		_jc_java_util_Collections__241$fields,
		.num_methods=		sizeof(_jc_java_util_Collections__241$methods) / sizeof(*_jc_java_util_Collections__241$methods),
		.methods=		_jc_java_util_Collections__241$methods,
		.instanceof_hash_table=	_jc_java_util_Collections__241$instanceof_hash_table,
		.num_class_depends=		sizeof(_jc_java_util_Collections__241$class_depends) / sizeof(*_jc_java_util_Collections__241$class_depends),
		.class_depends=		_jc_java_util_Collections__241$class_depends,
	    }
	}
    },
    .vtable= {
	.java_lang_Object= {
	    .clone$b75f2713d6705f70=
		&_jc_java_lang_Object$method$clone$b75f2713d6705f70,
	    .equals$8a15e0625571c581=
		&_jc_java_lang_Object$method$equals$8a15e0625571c581,
	    .finalize$660a5b5b608ff21f=
		&_jc_java_lang_Object$method$finalize$660a5b5b608ff21f,
	    .getClass$1f1ddb358c8ea7be=
		&_jc_java_lang_Object$method$getClass$1f1ddb358c8ea7be,
	    .hashCode$53152098849316df=
		&_jc_java_lang_Object$method$hashCode$53152098849316df,
	    .notify$36cb33b21c887fbf=
		&_jc_java_lang_Object$method$notify$36cb33b21c887fbf,
	    .notifyAll$3965af7f7c4f2978=
		&_jc_java_lang_Object$method$notifyAll$3965af7f7c4f2978,
	    .toString$7ea43b33b80a3070=
		&_jc_java_lang_Object$method$toString$7ea43b33b80a3070,
	    .wait$b5c8f990d7547e7d=
		&_jc_java_lang_Object$method$wait$b5c8f990d7547e7d,
	    .wait$5aedd5d0ce2db494=
		&_jc_java_lang_Object$method$wait$5aedd5d0ce2db494,
	    .wait$5175bc722fb3a6fa=
		&_jc_java_lang_Object$method$wait$5175bc722fb3a6fa,
	},
	.java_util_Collections__241= {
	    .hasMoreElements$95fbe58f36adadb0=
		&_jc_java_util_Collections__241$method$hasMoreElements$95fbe58f36adadb0,
	    .nextElement$9b7c3789fa3ba818=
		&_jc_java_util_Collections__241$method$nextElement$9b7c3789fa3ba818,
	},
    }
};
